# Pip installable version of OmniFold

This repository contains simple examples of implementing the OmniFold algorithm originally described in [Phys. Rev. Lett. 124 (2020) 182001](https://dx.doi.org/10.1103/PhysRevLett.124.182001), [1911.09107 [hep-ph]](https://arxiv.org/abs/1911.09107).  The code for the original paper can be found at [this repository](https://github.com/ericmetodiev/OmniFold), which includes a [binder demo](https://mybinder.org/v2/gh/ericmetodiev/OmniFold/master).  This repository was created to maintain a simple version of the OmniFold algorithm that can be pip installed as:

```bash
pip install unbinned-unfold==0.1.7
```

For a simple example see the notebooks OmniFold_example.ipynb and OmniFold_example_pc.ipynb